@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: latexmacros.ml,v 1.52 2004/06/30 07:05:35 filliatr Exp $ i*)
+(*i $Id: latexmacros.ml,v 1.54 2005/09/22 08:44:23 filliatr Exp $ i*)
 
 (*s This code is Copyright (C) 1997  Xavier Leroy. *)
 
@@ -160,64 +160,74 @@ def "\\TH" [Print "&THORN;"];
 def "\\dh" [Print "&eth;"];
 def "\\DH" [Print "&ETH;"];
 def "\\ss" [Print "&szlig;"];
-def "\\'" [Raw_arg(function "e" -> print_c ''
-                          | "E" -> print_c ''
-			  | "a" -> print_c ''
-			  | "A" -> print_c ''
-			  | "o" -> print_c ''
-			  | "O" -> print_c ''
-			  | "i" -> print_c ''
-                          | "\\i" -> print_c ''
-			  | "I" -> print_c ''
-			  | "u" -> print_c ''
-			  | "U" -> print_c ''
+def "\\'" [Raw_arg(function "e" -> print_s "&eacute;"
+                          | "E" -> print_s "&Eacute;"
+			  | "a" -> print_s "&aacute;"
+			  | "A" -> print_s "&Aacute;"
+			  | "o" -> print_s "&oacute;"
+			  | "O" -> print_s "&Oacute;"
+			  | "i" -> print_s "&iacute;"
+                          | "\\i" -> print_s "&iacute;"
+			  | "I" -> print_s "&Iacute;"
+			  | "u" -> print_s "&uacute;"
+			  | "U" -> print_s "&Uacute;"
+			  | "'"  -> print_s "&rdquo;"
+			  | "c" -> print_s "&#263;"
 			  | ""  -> print_c '\''
                           | s   -> print_s s)];
-def "\\`" [Raw_arg(function "e" -> print_c ''
-                          | "E" -> print_c ''
-                          | "a" -> print_c ''
-                          | "A" -> print_c ''
-			  | "o" -> print_c ''
-			  | "O" -> print_c ''
-			  | "i" -> print_c ''
-                          | "\\i" -> print_c ''
-			  | "I" -> print_c ''
-                          | "u" -> print_c ''
-                          | "U" -> print_c ''
-			  | ""  -> print_c '`'
+def "\\`" [Raw_arg(function "e" -> print_s "&egrave;"
+                          | "E" -> print_s "&Egrave;"
+                          | "a" -> print_s "&agrave;"
+                          | "A" -> print_s "&Agrave;"
+			  | "o" -> print_s "&ograve;"
+			  | "O" -> print_s "&Ograve;"
+			  | "i" -> print_s "&igrave;"
+                          | "\\i" -> print_s "&igrave;"
+			  | "I" -> print_s "&Igrave;"
+                          | "u" -> print_s "&ugrave;"
+                          | "U" -> print_s "&Ugrave;"
+			  | "`"  -> print_s "&ldquo;"
+			  | ""  -> print_s "&lsquo;"
                           | s   -> print_s s)];
-def "\\~" [Raw_arg(function "n" -> print_c ''
-		          | ""  -> print_c '~'
+def "\\~" [Raw_arg(function "n" -> print_s "&ntilde;"
+		          | ""  -> print_s "&tilde;"
                           | s   -> print_s s)];
-def "\\c" [Raw_arg(function "c" -> print_c ''
+def "\\c" [Raw_arg(function "c" -> print_s "&ccedil;"
                           | s   -> print_s s)];
-def "\\^" [Raw_arg(function "a" -> print_c ''
-                          | "A" -> print_c ''
-                          | "e" -> print_c ''
-                          | "E" -> print_c ''
-                          | "i" -> print_c ''
-                          | "\\i" -> print_c ''
-                          | "I" -> print_c ''
-                          | "o" -> print_c ''
-                          | "O" -> print_c ''
-                          | "u" -> print_c ''
-                          | "U" -> print_c ''
+def "\\^" [Raw_arg(function "a" -> print_s "&acirc;"
+                          | "A" -> print_s "&Acirc;"
+                          | "e" -> print_s "&ecirc;"
+                          | "E" -> print_s "&Ecirc;"
+                          | "i" -> print_s "&icirc;"
+                          | "\\i" -> print_s "&icirc;"
+                          | "I" -> print_s "&Icirc;"
+                          | "o" -> print_s "&ocirc;"
+                          | "O" -> print_s "&Ocirc;"
+                          | "u" -> print_s "&ucirc;"
+                          | "U" -> print_s "&Ucirc;"
 			  | ""  -> print_c '^'
                           | s   -> print_s s)];
-def "\\\"" [Raw_arg(function "e" -> print_c ''
-                          | "E" -> print_c ''
-                          | "a" -> print_c ''
-                          | "A" -> print_c ''
-                          | "\\i" -> print_c ''
-                          | "i" -> print_c ''
-                          | "I" -> print_c ''
-                          | "o" -> print_c ''
-                          | "O" -> print_c ''
-                          | "u" -> print_c ''
-                          | "U" -> print_c ''
+def "\\\"" [Raw_arg(function "e" -> print_s "&euml;"
+                          | "E" -> print_s "&Euml;"
+                          | "a" -> print_s "&auml;"
+                          | "A" -> print_s "&Auml;"
+                          | "\\i" -> print_s "&iuml;"
+                          | "i" -> print_s "&iuml;"
+                          | "I" -> print_s "&Iuml;"
+                          | "o" -> print_s "&ouml;"
+                          | "O" -> print_s "&Ouml;"
+                          | "u" -> print_s "&uuml;"
+                          | "U" -> print_s "&Uuml;"
                           | s   -> print_s s)];
 def "\\u" [Raw_arg print_s ];
-def "\\v" [Raw_arg print_s ];
+def "\\v" [Raw_arg(function "r" -> print_s "&#X0159;"
+                          | "R" -> print_s "&#X0158;"
+                          | "s" -> print_s "&#X0161;"
+                          | "S" -> print_s "&#X0160;"
+                          | "\\i" -> print_s "&#X012D;"
+                          | "i" -> print_s "&#X012D;"
+                          | "I" -> print_s "&#X012C;"
+			  | s   -> print_s s)];
 
 (* Math macros *)
 def "\\[" [Print "<blockquote>"];
@@ -286,6 +296,10 @@ def "\\bigskip" [];
 def "\\relax" [];
 def "\\markboth" [Skip_arg; Skip_arg];
 def "\\dots" [Print "..."];
+def "\\dot" [Print "."];
+def "\\simeq" [Print "&tilde;="];
+def "\\approx" [Print "&tilde;"];
+def "\\^circ" [Print "&deg;"];
 def "\\ldots" [Print "..."];
 def "\\cdot" [Print "&#183;"];
 def "\\cdots" [Print "..."];
@@ -479,4 +493,3 @@ let init_style_macros st =
 	"\\Btxinshort", "In:";
       ]
   end
-
